@@ -759,7 +759,7 @@ public:
   Id* sBOT_NOT;        // NOLINT(readability-identifier-naming)
 
   OpToString() {
-    GCLock lock;
+    GC::lockNoGC();
 
     sBOT_PLUS = new Id(Location(), "'+'", nullptr);
     sBOT_MINUS = new Id(Location(), "'-'", nullptr);
@@ -790,6 +790,8 @@ public:
     sBOT_XOR = new Id(Location(), "'xor'", nullptr);
     sBOT_DOTDOT = new Id(Location(), "'..'", nullptr);
     sBOT_NOT = new Id(Location(), "'not'", nullptr);
+
+    GC::unlock();
   }
 
   static OpToString& o() {
@@ -995,7 +997,7 @@ Call* Call::commutativeNormalized(EnvI& env, const Call* orig) {
               return xs->max(i) < ys->max(i);
             }
           }
-          return true;  // equal
+          return false;  // equal
         }
         FloatSetVal* xs = Expression::cast<SetLit>(x)->fsv();
         FloatSetVal* ys = Expression::cast<SetLit>(y)->fsv();
@@ -1010,7 +1012,7 @@ Call* Call::commutativeNormalized(EnvI& env, const Call* orig) {
             return xs->max(i) < ys->max(i);
           }
         }
-        return true;  // equal
+        return false;  // equal
       }
       default: {
         return x < y;
@@ -1327,7 +1329,7 @@ bool TypeInst::resolveAlias(EnvI& env) {
     isArrayOfArray = true;
   }
 
-  if (type().tiExplicit() && ntype.ti() != type().ti()) {
+  if (type().tiExplicit()) {
     if (type().ti() == Type::TI_VAR) {
       ntype.mkVar(env);
     } else {
@@ -1567,13 +1569,13 @@ Type return_type(EnvI& env, FunctionI* fi, const std::vector<T>& ta, Expression*
     if (tii->ranges().size() == 1 && isa_tiid(tii->ranges()[0]->domain())) {
       ASTString tiid = Expression::cast<TIId>(tii->ranges()[0]->domain())->v();
       Type orig_tiit = get_type(cur.second);
-      if (orig_tiit.dim() == 0) {
+      if (orig_tiit.dim() == 0 && !orig_tiit.isSet()) {
         std::ostringstream ss;
         ss << "type-inst variable $" << tiid << " must be an array index";
         throw TypeError(env, get_loc(cur.second, call, fi), ss.str());
       }
-      Type tiit = Type::top(orig_tiit.dim());
-      if (orig_tiit.typeId() != 0) {
+      Type tiit = Type::top(orig_tiit.dim() == 0 && orig_tiit.isSet() ? 1 : orig_tiit.dim());
+      if (orig_tiit.typeId() != 0 && orig_tiit.dim() != 0) {
         std::vector<unsigned int> enumIds = env.getArrayEnum(orig_tiit.typeId());
         enumIds[enumIds.size() - 1] = 0;
         tiit.typeId(env.registerArrayEnum(enumIds));
@@ -1652,14 +1654,20 @@ Type type_from_tmap(EnvI& env, TypeInst* ti, const ASTStringMap<std::pair<Type,
       }
     }
     std::vector<Type> fields(al->size() + (isArrayOfArray ? 1U : 0U));
+    bool isVar = false;
     for (unsigned int i = 0; i < al->size(); i++) {
       fields[i] = type_from_tmap(env, Expression::cast<TypeInst>((*al)[i]), tmap);
       ret.cv(ret.cv() || fields[i].cv());
+      isVar |= fields[i].isvar();
     }
     if (isArrayOfArray) {
       fields[al->size()] = Type();
     }
-    unsigned int typeId = 0;
+    unsigned int typeId = ret.typeId();
+    ret.typeId(0);
+    ret.ti(isVar ? Type::TI_VAR : Type::TI_PAR);
+    ret.typeId(typeId);
+    typeId = 0;
     if (ret.bt() == Type::BT_TUPLE) {
       typeId = env.registerTupleType(fields);
     } else {
@@ -1742,6 +1750,12 @@ Type type_from_tmap(EnvI& env, TypeInst* ti, const ASTStringMap<std::pair<Type,
       }
       enumIds[enumIds.size() - 1] = curTypeId;
       ret.typeId(env.registerArrayEnum(enumIds));
+    } else if (ret.dim() > 0 && ret.typeId() != 0) {
+      std::vector<unsigned int> enumIds(it->second.first.dim() + 1, 0);
+      const auto& curIds = env.getArrayEnum(curTypeId);
+      curTypeId = curIds[curIds.size() - 1];
+      enumIds[enumIds.size() - 1] = curTypeId;
+      ret.typeId(env.registerArrayEnum(enumIds));
     }
   } else if (!ti->ranges().empty()) {
     std::vector<unsigned int> enumIds(ti->ranges().size() + 1);
@@ -1789,8 +1803,8 @@ void Item::mark(Item* item) {
     case Item::II_VD:
       item->_gcMark = 0;  // need to reset so that Expression::mark works
       Expression::mark(item->cast<VarDeclI>()->e());
-#if defined(MINIZINC_GC_STATS)
-      GC::stats()[item->cast<VarDeclI>()->e()->Expression::eid()].inmodel++;
+#ifdef MINIZINC_GC_STATS
+      GC::stats()[MiniZinc::Expression::eid(item->cast<VarDeclI>()->e())].inmodel++;
 #endif
       break;
     case Item::II_ASN:
@@ -1800,8 +1814,8 @@ void Item::mark(Item* item) {
       break;
     case Item::II_CON:
       Expression::mark(item->cast<ConstraintI>()->e());
-#if defined(MINIZINC_GC_STATS)
-      GC::stats()[item->cast<ConstraintI>()->e()->Expression::eid()].inmodel++;
+#ifdef MINIZINC_GC_STATS
+      GC::stats()[MiniZinc::Expression::eid(item->cast<ConstraintI>()->e())].inmodel++;
 #endif
       break;
     case Item::II_SOL: {
@@ -2145,7 +2159,7 @@ bool Expression::equalInternal(const Expression* e0, const Expression* e1) {
 }
 
 Constants::Constants() {
-  GCLock lock;
+  GC::lockNoGC();
   auto* ti = new TypeInst(Location(), Type::parbool());
   emptyBoolArray = new ArrayLit(Location(), std::vector<Expression*>{});
   emptyBoolArray->type(Type::parbool(1));
@@ -2513,6 +2527,7 @@ Constants::Constants() {
   cli_cat.io = addString("Input/Output Options");
   cli_cat.solver = addString("Solver Options");
   cli_cat.translation = addString("Translation Options");
+  GC::unlock();
 };
 
 bool Constants::isCallByReferenceId(const ASTString& cid) const {
