@@ -170,6 +170,20 @@ bool cannot_use_rhs_for_output(EnvI& env, Expression* e,
               rt.mkPar(env);
               decl->ti()->type(rt);
 
+              class MakeBodyPar : public EVisitor {
+              public:
+                EnvI& env;
+                MakeBodyPar(EnvI& env0) : env(env0) {}
+                bool enter(Expression* e) {
+                  Type t(Expression::type(e));
+                  t.mkPar(env);
+                  t.cv(false);
+                  Expression::type(e, t);
+                  return true;
+                }
+              } _mbp(env);
+              top_down(_mbp, decl->e());
+
               CollectOccurrencesE ce(env, env.outputVarOccurrences, decl);
               top_down(ce, decl->e());
               top_down(ce, decl->ti());
@@ -1036,7 +1050,7 @@ Expression* create_dzn_output(EnvI& e, bool includeObjective, bool includeOutput
             Comprehension* indexes;
             Comprehension* values;
             auto* index_set = Call::a(Location().introduce(), "index_set", {vd->id()});
-            index_set->type(Type::varsetint());
+            index_set->type(Type::parsetint());
             index_set->decl(e.model->matchFn(e, index_set, false));
 
             {
@@ -1070,7 +1084,17 @@ Expression* create_dzn_output(EnvI& e, bool includeObjective, bool includeOutput
               vd_t.typeId(xEnumId);
               aa->type(vd_t);
 
-              auto* show_i = Call::a(Location().introduce(), ASTString("showDzn"), {aa});
+              Expression* aa_e = aa;
+              if (vd_t.istuple()) {
+                auto* tupleType = e.getTupleType(vd_t);
+                if (tupleType->size() == 2 && (*tupleType)[1].isunknown()) {
+                  // Yes: insert field access
+                  aa_e = new FieldAccess(Expression::loc(aa).introduce(), aa, IntLit::a(1));
+                  Expression::type(aa_e, (*tupleType)[0]);
+                }
+              }
+
+              auto* show_i = Call::a(Location().introduce(), ASTString("showDzn"), {aa_e});
               show_i->type(Type::parstring());
               FunctionI* fi = e.model->matchFn(e, show_i, false);
               assert(fi);
@@ -1180,7 +1204,17 @@ Expression* create_dzn_output(EnvI& e, bool includeObjective, bool includeOutput
               vd_t.typeId(xEnumId);
               aa->type(vd_t);
 
-              auto* show_i = Call::a(Location().introduce(), ASTString("showDzn"), {aa});
+              Expression* aa_e = aa;
+              if (vd_t.istuple()) {
+                auto* tupleType = e.getTupleType(vd_t);
+                if (tupleType->size() == 2 && (*tupleType)[1].isunknown()) {
+                  // Yes: insert field access
+                  aa_e = new FieldAccess(Expression::loc(aa).introduce(), aa, IntLit::a(1));
+                  Expression::type(aa_e, (*tupleType)[0]);
+                }
+              }
+
+              auto* show_i = Call::a(Location().introduce(), ASTString("showDzn"), {aa_e});
               show_i->type(Type::parstring());
               FunctionI* fi = e.model->matchFn(e, show_i, false);
               assert(fi);
@@ -1580,17 +1614,26 @@ void create_output(EnvI& e, FlatteningOptions::OutputMode outputMode, bool outpu
   OutputI* outputItem = nullptr;
   GCLock lock;
 
+  // Let items to ensure output with side effects is only evaluated once
+  std::vector<Expression*> let_items;
+
   // Combine output sections into one string
   bool generateDefault = e.outputSections.noUserDefined();
   Expression* o = nullptr;
-  for (const auto& it : e.outputSections) {
+  for (auto& it : e.outputSections) {
     if (!e.outputSectionEnabled(it.section)) {
       continue;
     }
+    ASTExprVec<TypeInst> r({new TypeInst(Location().introduce(), Type::parint())});
+    auto* ti = new TypeInst(Location().introduce(), Expression::type(it.e), r);
+    auto* vd = new VarDecl(Location().introduce(), ti, e.genId(), it.e);
+    vd->toplevel(false);
+    it.e = vd->id();
+    let_items.push_back(vd);
     if (o == nullptr) {
-      o = it.e;
+      o = vd->id();
     } else {
-      o = new BinOp(Location().introduce(), o, BOT_PLUSPLUS, it.e);
+      o = new BinOp(Location().introduce(), o, BOT_PLUSPLUS, vd->id());
       Expression::type(o, Type::parstring(1));
     }
   }
@@ -1641,6 +1684,10 @@ void create_output(EnvI& e, FlatteningOptions::OutputMode outputMode, bool outpu
     o = new ArrayLit(Location().introduce(), std::vector<Expression*>());
     Expression::type(o, Type::parstring(1));
   }
+  if (!let_items.empty()) {
+    o = new Let(Location().introduce(), let_items, o);
+    Expression::type(o, Type::parstring(1));
+  }
   auto* newOutputItem = new OutputI(Location().introduce(), o);
   e.model->addItem(newOutputItem);
 
@@ -1818,7 +1865,11 @@ void create_output(EnvI& e, FlatteningOptions::OutputMode outputMode, bool outpu
                   Expression::addAnnotation(vd_followed->flat(), env.constants.ann.output_var);
                   check_rename_var(env, vd_followed, {}, 0);
                 } else {
-                  bool needOutputAnn = true;
+                  // We need to create an output annotation for the FlatZinc decl,
+                  // but only if it is NOT an optional type (those can't be output),
+                  // and if none of the contents of its array literal (if present)
+                  // has a reverse mapper.
+                  bool needOutputAnn = !reallyFlat->type().isOpt();
                   if (auto* al = Expression::dynamicCast<ArrayLit>(reallyFlat->e())) {
                     for (unsigned int i = 0; i < al->size(); i++) {
                       if (Id* id = Expression::dynamicCast<Id>((*al)[i])) {
@@ -2013,7 +2064,7 @@ void finalise_output(EnvI& e) {
                 if (e.varOccurrences.occurrences(reallyFlat) == 0 && reallyFlat->e() == nullptr) {
                   auto it = e.varOccurrences.idx.find(reallyFlat->id());
                   assert(it.first);
-                  e.flatRemoveItem((*e.flat())[*it.second]->cast<VarDeclI>());
+                  e.flatRemoveItem((*e.flat())[*it.second] -> cast<VarDeclI>());
                 }
               } else {
                 // If the VarDecl does not have a usable right hand side, it needs to be
@@ -2037,7 +2088,7 @@ void finalise_output(EnvI& e) {
                     if (e.varOccurrences.occurrences(reallyFlat) == 0) {
                       auto it = e.varOccurrences.idx.find(reallyFlat->id());
                       assert(it.first);
-                      e.flatRemoveItem((*e.flat())[*it.second]->cast<VarDeclI>());
+                      e.flatRemoveItem((*e.flat())[*it.second] -> cast<VarDeclI>());
                     }
                   }
                 } else if (auto* al = Expression::dynamicCast<ArrayLit>(reallyFlat->e())) {
@@ -2056,7 +2107,7 @@ void finalise_output(EnvI& e) {
                     if (e.varOccurrences.occurrences(reallyFlat) == 0) {
                       auto it = e.varOccurrences.idx.find(reallyFlat->id());
                       assert(it.first);
-                      e.flatRemoveItem((*e.flat())[*it.second]->cast<VarDeclI>());
+                      e.flatRemoveItem((*e.flat())[*it.second] -> cast<VarDeclI>());
                     }
                     vd->e(copy(e, e.cmap, al));
                     Type al_t(Expression::type(vd->e()));
