@@ -175,12 +175,8 @@ public:
       _os << "any";
       return;
     }
-    switch (type.ti()) {
-      case Type::TI_PAR:
-        break;
-      case Type::TI_VAR:
-        _os << "var ";
-        break;
+    if (type.isvar() && !type.structBT()) {
+      _os << "var ";
     }
     if (type.ot() == Type::OT_OPTIONAL) {
       _os << "opt ";
@@ -251,6 +247,14 @@ public:
       // TODO: Why does `type` sometimes not have a type ID even though `al` does?
       auto t = al->type().structBT() ? al->type() : type;
       assert(t.structBT());
+      if (_env != nullptr && t.bt() == Type::BT_TUPLE && t.typeId() != 0) {
+        auto* tt = _env->getTupleType(t);
+        if (tt->size() == 2 && (*tt)[1].isunknown()) {
+          // This is an array of arrays - print first component only
+          p((*tt)[0], (*al)[0]);
+          return;
+        }
+      }
       _os << (t.bt() == Type::BT_TUPLE ? "tuple(" : "record(");
       if (t.bt() != Type::BT_RECORD || t.typeId() != 0) {
         for (unsigned int i = 0; i < al->size(); ++i) {
@@ -400,6 +404,14 @@ public:
         break;
       case Expression::E_ARRAYLIT: {
         const auto* al = Expression::cast<ArrayLit>(e);
+        if (_env != nullptr && al->type().bt() == Type::BT_TUPLE && al->type().typeId() != 0) {
+          auto* tt = _env->getTupleType(Expression::type(al));
+          if (tt->size() == 2 && (*tt)[1].isunknown()) {
+            // This is an array of arrays, print the first element
+            p((*al)[0]);
+            break;
+          }
+        }
         unsigned int n = al->dims();
         if (n == 1 && al->min(0) == 1) {
           _os << (al->isTuple() ? "(" : "[");
@@ -1270,12 +1282,8 @@ Document* tiexpression_to_document(const Type& type, const Expression* e, EnvI*
   if (type.any()) {
     dl->addStringToList("any ");
   } else {
-    switch (type.ti()) {
-      case Type::TI_PAR:
-        break;
-      case Type::TI_VAR:
-        dl->addStringToList("var ");
-        break;
+    if (type.isvar() && !type.structBT()) {
+      dl->addStringToList("var ");
     }
     if (type.ot() == Type::OT_OPTIONAL) {
       dl->addStringToList("opt ");
@@ -1475,6 +1483,13 @@ public:
   static ret mapAnonVar(const AnonVar* /*v*/) { return new StringDocument("_"); }
   ret mapArrayLit(const ArrayLit* al) {
     /// TODO: test multi-dimensional arrays handling
+    if (_env != nullptr && al->type().bt() == Type::BT_TUPLE && al->type().typeId() != 0) {
+      auto* tt = _env->getTupleType(Expression::type(al));
+      if (tt->size() == 2 && (*tt)[1].isunknown()) {
+        // This is an array of arrays, print the first element
+        return expression_to_document((*al)[0], _env);
+      }
+    }
     DocumentList* dl;
     unsigned int n = al->dims();
     if (n == 1 && al->min(0) == 1) {
