@@ -220,58 +220,269 @@ vector<MiniZinc::SolverConfig::ExtraFlag> MIPxpressWrapper::getExtraFlags(
     // Using string parameter names because there doesn't seem to be a way to recover
     // the name from a parameter ID number
     static std::vector<std::string> all_params = {
-        "algaftercrossover", "algafternetwork", "autoperturb", "backtrack", "backtracktie",
-        "baralg", "barcrash", "bardualstop", "barfreescale", "bargapstop", "bargaptarget",
-        "barindeflimit", "bariterlimit", "barkernel", "barobjscale", "barorder", "barorderthreads",
-        "baroutput", "barpresolveops", "barprimalstop", "barregularize", "barrhsscale",
-        "barsolution", "barstart", "barstartweight", "barstepstop", "barthreads", "barcores",
-        "bigm", "bigmmethod", "branchchoice", "branchdisj", "branchstructural", "breadthfirst",
-        "cachesize", "callbackfrommasterthread", "choleskyalg", "choleskytol", "conflictcuts",
-        "concurrentthreads", "corespercpu", "covercuts", "cpuplatform", "cputime", "crash",
-        "crossover", "crossoveraccuracytol", "crossoveriterlimit", "crossoverops",
-        "crossoverthreads", "cstyle", "cutdepth", "cutfactor", "cutfreq", "cutstrategy",
-        "cutselect", "defaultalg", "densecollimit", "deterministic", "dualgradient", "dualize",
-        "dualizeops", "dualperturb", "dualstrategy", "dualthreads", "eigenvaluetol", "elimfillin",
-        "elimtol", "etatol", "extracols", "extraelems", "extramipents", "extrapresolve",
-        "extraqcelements", "extraqcrows", "extrarows", "extrasetelems", "extrasets",
-        "feasibilitypump", "feastol", "feastoltarget", "forceoutput", "forceparalleldual",
-        "globalfilebias", "globalfileloginterval", "gomcuts", "heurbeforelp", "heurdepth",
-        "heurdiveiterlimit", "heurdiverandomize", "heurdivesoftrounding", "heurdivespeedup",
-        "heurdivestrategy", "heurforcespecialobj", "heurfreq", "heurmaxsol", "heurnodes",
-        "heursearcheffort", "heursearchfreq", "heursearchrootcutfreq", "heursearchrootselect",
-        "heursearchtreeselect", "heurstrategy", "heurthreads", "historycosts", "ifcheckconvexity",
-        "indlinbigm", "indprelinbigm", "invertfreq", "invertmin", "keepbasis", "keepnrows",
-        "l1cache", "linelength", "lnpbest", "lnpiterlimit", "lpflags", "lpiterlimit",
-        "lprefineiterlimit", "localchoice", "lpfolding", "lplog", "lplogdelay", "lplogstyle",
-        "lpthreads", "markowitztol", "matrixtol", "maxchecksonmaxcuttime", "maxchecksonmaxtime",
-        "maxmcoeffbufferelems", "maxcuttime", "maxglobalfilesize", "maxiis", "maximpliedbound",
-        "maxlocalbacktrack", "maxmemoryhard", "maxmemorysoft", "maxmiptasks", "maxmipsol",
-        "maxnode", "maxpagelines", "maxscalefactor", "maxtime", "mipabscutoff", "mipabsgapnotify",
-        "mipabsgapnotifybound", "mipabsgapnotifyobj", "mipabsstop", "mipaddcutoff",
-        "mipdualreductions", "mipfracreduce", "mipkappafreq", "miplog", "mippresolve", "miprampup",
-        "miqcpalg", "miprefineiterlimit", "miprelcutoff", "miprelgapnotify", "miprelstop",
-        "mipterminationmethod", "mipthreads", "miptol", "miptoltarget", "mps18compatible",
-        "mpsboundname", "mpsecho", "mpsformat", "mpsobjname", "mpsrangename", "mpsrhsname",
-        "mutexcallbacks", "netcuts", "nodeselection", "objscalefactor", "optimalitytol",
-        "optimalitytoltarget", "outputlog", "outputmask", "outputtol", "penalty", "perturb",
-        "pivottol", "ppfactor", "preanalyticcenter", "prebasisred", "prebndredcone",
-        "prebndredquad", "precoefelim", "precomponents", "precomponentseffort", "preconedecomp",
-        "preconvertseparable", "predomcol", "predomrow", "preduprow", "preelimquad",
-        "preimplications", "prelindep", "preobjcutdetect", "prepermute", "prepermuteseed",
-        "preprobing", "preprotectdual", "presolve", "presolvemaxgrow", "presolveops",
-        "presolvepasses", "presort", "pricingalg", "primalops", "primalperturb", "primalunshift",
-        "pseudocost", "qccuts", "qcrootalg", "qsimplexops", "quadraticunshift",
+        "algaftercrossover",
+        "algafternetwork",
+        "autoperturb",
+        "backtrack",
+        "backtracktie",
+        "baralg",
+        "barcrash",
+        "bardualstop",
+        "barfreescale",
+        "bargapstop",
+        "bargaptarget",
+        "barindeflimit",
+        "bariterlimit",
+        "barkernel",
+        "barobjscale",
+        "barorder",
+        "barorderthreads",
+        "baroutput",
+        "barpresolveops",
+        "barprimalstop",
+        "barregularize",
+        "barrhsscale",
+        "barsolution",
+        "barstart",
+        "barstartweight",
+        "barstepstop",
+        "barthreads",
+        "barcores",
+        "bigm",
+        "bigmmethod",
+        "branchchoice",
+        "branchdisj",
+        "branchstructural",
+        "breadthfirst",
+        "cachesize",
+        "callbackfrommasterthread",
+        "choleskyalg",
+        "choleskytol",
+        "conflictcuts",
+        "concurrentthreads",
+        "corespercpu",
+        "covercuts",
+        "cpuplatform",
+        "cputime",
+        "crash",
+        "crossover",
+        "crossoveraccuracytol",
+        "crossoveriterlimit",
+        "crossoverops",
+        "crossoverthreads",
+        "cstyle",
+        "cutdepth",
+        "cutfactor",
+        "cutfreq",
+        "cutstrategy",
+        "cutselect",
+        "defaultalg",
+        "densecollimit",
+        "deterministic",
+        "dualgradient",
+        "dualize",
+        "dualizeops",
+        "dualperturb",
+        "dualstrategy",
+        "dualthreads",
+        "eigenvaluetol",
+        "elimfillin",
+        "elimtol",
+        "etatol",
+        "extracols",
+        "extraelems",
+        "extramipents",
+        "extrapresolve",
+        "extraqcelements",
+        "extraqcrows",
+        "extrarows",
+        "extrasetelems",
+        "extrasets",
+        "feasibilitypump",
+        "feastol",
+        "feastoltarget",
+        "forceoutput",
+        "forceparalleldual",
+        "globalfilebias",
+        "globalfileloginterval",
+        "gomcuts",
+        "heurbeforelp",
+        "heurdepth",
+        "heurdiveiterlimit",
+        "heurdiverandomize",
+        "heurdivesoftrounding",
+        "heurdivespeedup",
+        "heurdivestrategy",
+        "heurforcespecialobj",
+        "heurfreq",
+        "heurmaxsol",
+        "heurnodes",
+        "heursearcheffort",
+        "heursearchfreq",
+        "heursearchrootcutfreq",
+        "heursearchrootselect",
+        "heursearchtreeselect",
+        "heurstrategy",
+        "heurthreads",
+        "historycosts",
+        "ifcheckconvexity",
+        "indlinbigm",
+        "indprelinbigm",
+        "invertfreq",
+        "invertmin",
+        "keepbasis",
+        "keepnrows",
+        "l1cache",
+        "linelength",
+        "lnpbest",
+        "lnpiterlimit",
+        "lpflags",
+        "lpiterlimit",
+        "lprefineiterlimit",
+        "localchoice",
+        "lpfolding",
+        "lplog",
+        "lplogdelay",
+        "lplogstyle",
+        "lpthreads",
+        "markowitztol",
+        "matrixtol",
+        "maxchecksonmaxcuttime",
+        "maxchecksonmaxtime",
+        "maxmcoeffbufferelems",
+        "maxcuttime",
+        "maxglobalfilesize",
+        "maxiis",
+        "maximpliedbound",
+        "maxlocalbacktrack",
+        "maxmemoryhard",
+        "maxmemorysoft",
+        "maxmiptasks",
+        "maxmipsol",
+        "maxnode",
+        "maxpagelines",
+        "maxscalefactor",
+        "maxtime",
+        "mipabscutoff",
+        "mipabsgapnotify",
+        "mipabsgapnotifybound",
+        "mipabsgapnotifyobj",
+        "mipabsstop",
+        "mipaddcutoff",
+        "mipdualreductions",
+        "mipfracreduce",
+        "mipkappafreq",
+        "miplog",
+        "mippresolve",
+        "miprampup",
+        "miqcpalg",
+        "miprefineiterlimit",
+        "miprelcutoff",
+        "miprelgapnotify",
+        "miprelstop",
+        "mipterminationmethod",
+        "mipthreads",
+        "miptol",
+        "miptoltarget",
+        "mps18compatible",
+        "mpsboundname",
+        "mpsecho",
+        "mpsformat",
+        "mpsobjname",
+        "mpsrangename",
+        "mpsrhsname",
+        "mutexcallbacks",
+        "netcuts",
+        "nodeselection",
+        "objscalefactor",
+        "optimalitytol",
+        "optimalitytoltarget",
+        "outputlog",
+        "outputmask",
+        "outputtol",
+        "penalty",
+        "perturb",
+        "pivottol",
+        "ppfactor",
+        "preanalyticcenter",
+        "prebasisred",
+        "prebndredcone",
+        "prebndredquad",
+        "precoefelim",
+        "precomponents",
+        "precomponentseffort",
+        "preconedecomp",
+        "preconvertseparable",
+        "predomcol",
+        "predomrow",
+        "preduprow",
+        "preelimquad",
+        "preimplications",
+        "prelindep",
+        "preobjcutdetect",
+        "prepermute",
+        "prepermuteseed",
+        "preprobing",
+        "preprotectdual",
+        "presolve",
+        "presolvemaxgrow",
+        "presolveops",
+        "presolvepasses",
+        "presort",
+        "pricingalg",
+        "primalops",
+        "primalperturb",
+        "primalunshift",
+        "pseudocost",
+        "qccuts",
+        "qcrootalg",
+        "qsimplexops",
+        "quadraticunshift",
         //"randomseed",
-        "refactor", "refineops", "relaxtreememorylimit", "relpivottol", "repairindefiniteq",
-        "repairinfeasmaxtime", "resourcestrategy", "rootpresolve", "sbbest", "sbeffort",
-        "sbestimate", "sbiterlimit", "sbselect", "scaling", "sifting", "sleeponthreadwait",
-        "sosreftol", "symmetry", "symselect",
+        "refactor",
+        "refineops",
+        "relaxtreememorylimit",
+        "relpivottol",
+        "repairindefiniteq",
+        "repairinfeasmaxtime",
+        "resourcestrategy",
+        "rootpresolve",
+        "sbbest",
+        "sbeffort",
+        "sbestimate",
+        "sbiterlimit",
+        "sbselect",
+        "scaling",
+        "sifting",
+        "sleeponthreadwait",
+        "sosreftol",
+        "symmetry",
+        "symselect",
         //"threads",
-        "trace", "treecompression", "treecovercuts", "treecutselect", "treediagnostics",
-        "treegomcuts", "treememorylimit", "treememorysavingtarget", "treepresolve",
-        "treepresolve_keepbasis", "treeqccuts", "tunerhistory", "tunermaxtime", "tunermethod",
-        "tunermethodfile", "tunermode", "tuneroutput", "tuneroutputpath", "tunerpermute",
-        "tunerrootalg", "tunersessionname", "tunertarget", "tunerthreads", "usersolheuristic",
+        "trace",
+        "treecompression",
+        "treecovercuts",
+        "treecutselect",
+        "treediagnostics",
+        "treegomcuts",
+        "treememorylimit",
+        "treememorysavingtarget",
+        "treepresolve",
+        "treepresolve_keepbasis",
+        "treeqccuts",
+        "tunerhistory",
+        "tunermaxtime",
+        "tunermethod",
+        "tunermethodfile",
+        "tunermode",
+        "tuneroutput",
+        "tuneroutputpath",
+        "tunerpermute",
+        "tunerrootalg",
+        "tunersessionname",
+        "tunertarget",
+        "tunerthreads",
+        "usersolheuristic",
         "varselection",
         //"version"
     };
