@@ -1387,26 +1387,28 @@ void p_cumulatives(SolverInstanceBase& s, const Call* call) {
   }
 }
 
-void p_among_seq_int(SolverInstanceBase& s, const Call* call) {
+void p_sliding_among_int(SolverInstanceBase& s, const Call* call) {
   const Annotation& ann = Expression::ann(call);
   auto& gi = static_cast<GecodeSolverInstance&>(s);
-  Gecode::IntVarArgs x = gi.arg2intvarargs(call->arg(0));
-  IntSet S = gi.arg2intset(s.env().envi(), call->arg(1));
+
+  int l = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(0))).toInt());
+  int u = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(1))).toInt());
   int q = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(2))).toInt());
-  int l = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(3))).toInt());
-  int u = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(4))).toInt());
+  Gecode::IntVarArgs x = gi.arg2intvarargs(call->arg(3));
+  IntSet S = gi.arg2intset(s.env().envi(), call->arg(4));
   unshare(*gi.currentSpace, x);
   sequence(*gi.currentSpace, x, S, q, l, u, GecodeSolverInstance::ann2icl(ann));
 }
 
-void p_among_seq_bool(SolverInstanceBase& s, const Call* call) {
+void p_sliding_among_bool(SolverInstanceBase& s, const Call* call) {
   const Annotation& ann = Expression::ann(call);
   auto& gi = static_cast<GecodeSolverInstance&>(s);
-  BoolVarArgs x = gi.arg2boolvarargs(call->arg(0));
-  bool val = Expression::cast<BoolLit>(call->arg(1))->v();
+
+  int l = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(0))).toInt());
+  int u = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(1))).toInt());
   int q = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(2))).toInt());
-  int l = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(3))).toInt());
-  int u = static_cast<int>(IntLit::v(Expression::cast<IntLit>(call->arg(4))).toInt());
+  BoolVarArgs x = gi.arg2boolvarargs(call->arg(3));
+  bool val = Expression::cast<BoolLit>(call->arg(4))->v();
   IntSet S(static_cast<int>(val), static_cast<int>(val));
   unshare(*gi.currentSpace, x);
   sequence(*gi.currentSpace, x, S, q, l, u, GecodeSolverInstance::ann2icl(ann));
